@@ -19,7 +19,7 @@ class ClientProtocol(asyncio.Protocol):
         self.ins = ins
 
     def connection_made(self, transport):
-        logger.info("Connection made")
+        logger.debug("Connection made")
         self.transport = transport
 
     def data_received(self, data):
@@ -27,13 +27,13 @@ class ClientProtocol(asyncio.Protocol):
             self.transport.close()
         if data:
             self.ins.future.set_result(data)
-        logger.info("Data received: {!r}".format(data.decode()))
+        logger.debug("Data received: {!r}".format(data.decode()))
 
     def connection_lost(self, error):
         if error:
             logger.error('ERROR: {}'.format(error))
         else:
-            logger.info('The server closed the connection')
+            logger.debug('The server closed the connection')
 
 
 class EchoClientProtocol:
